@@ -38,6 +38,12 @@ ItemContainer::ItemContainer(QQuickItem *parent)
         setLayout(qobject_cast<AppletsLayout *>(parentItem()));
     });
 
+    connect(this, &ItemContainer::activeFocusChanged, this, [this]() {
+        if (!hasActiveFocus()) { // don't start edit mode if press caused a popup
+            m_editModeTimer->stop();
+        }
+    });
+
     connect(m_editModeTimer, &QTimer::timeout, this, [this]() {
         setEditMode(true);
     });
@@ -243,6 +249,7 @@ void ItemContainer::onConfigOverlayComponentStatusChanged(QQmlComponent::Status
 
     m_configOverlay->setVisible(false);
     m_configOverlay->setItemContainer(this);
+    m_configOverlay->setParent(this);
     m_configOverlay->setParentItem(this);
     m_configOverlay->setTouchInteraction(m_mouseSynthetizedFromTouch);
     m_configOverlay->setZ(999);
@@ -254,6 +261,12 @@ void ItemContainer::onConfigOverlayComponentStatusChanged(QQmlComponent::Status
 
     connect(m_configOverlay, &ConfigOverlay::openChanged, this, &ItemContainer::configOverlayVisibleChanged);
 
+    connect(m_configOverlay, &QQuickItem::visibleChanged, this, [&]() {
+        if (!m_configOverlay->isVisible()) {
+            unsetCursor();
+        }
+    });
+
     Q_EMIT configOverlayItemChanged();
 
     m_configOverlay->setOpen(m_configOverlayVisible);
@@ -444,6 +457,7 @@ void ItemContainer::sendUngrabRecursive(QQuickItem *item)
     }
 
     for (auto *child : item->childItems()) {
+        qApp->sendEvent(child, new QMouseEvent(QEvent::MouseButtonRelease, {}, {}, {}, Qt::NoButton, Qt::NoButton, Qt::KeyboardModifiers()));
         sendUngrabRecursive(child);
     }
 
@@ -563,20 +577,20 @@ void ItemContainer::mousePressEvent(QMouseEvent *event)
         m_editModeTimer->start(QGuiApplication::styleHints()->mousePressAndHoldInterval());
     }
 
-    m_lastMousePosition = event->scenePosition();
-    m_mouseDownPosition = event->scenePosition();
+    // Use positions mapped to parent and *not* scene positions because the whole appletsLayout might be zoomed or transformed
+    m_lastMousePosition = mapToItem(parentItem(), event->pos());
+    m_mouseDownPosition = m_lastMousePosition;
     event->accept();
 }
 
 void ItemContainer::mouseReleaseEvent(QMouseEvent *event)
 {
-    Q_UNUSED(event);
-
     if (!m_layout || (!m_editMode && m_editModeCondition == Manual)) {
         return;
     }
 
     m_mouseDown = false;
+    m_lastMousePositionOnGrid = QPoint(-1, -1);
     m_mouseSynthetizedFromTouch = false;
     m_editModeTimer->stop();
     if (event->exclusiveGrabber(event->point(0)) == this) {
@@ -602,7 +616,10 @@ void ItemContainer::mouseMoveEvent(QMouseEvent *event)
         return;
     }
 
-    if (!m_editMode && QPointF(event->scenePosition() - m_mouseDownPosition).manhattanLength() >= QGuiApplication::styleHints()->startDragDistance()) {
+    // Use positions mapped to parent and *not* scene positions because the whole appletsLayout might be zoomed or transformed
+    const QPointF parentPos = mapToItem(parentItem(), event->pos());
+
+    if (!m_editMode && QPointF(parentPos - m_mouseDownPosition).manhattanLength() >= QGuiApplication::styleHints()->startDragDistance()) {
         if (m_editModeCondition == AfterPress) {
             setEditMode(true);
         } else {
@@ -621,15 +638,18 @@ void ItemContainer::mouseMoveEvent(QMouseEvent *event)
         Q_EMIT dragActiveChanged();
 
     } else {
-        setPosition(QPointF(x() + event->scenePosition().x() - m_lastMousePosition.x(), y() + event->scenePosition().y() - m_lastMousePosition.y()));
+        setPosition(QPointF(x() + parentPos.x() - m_lastMousePosition.x(), y() + parentPos.y() - m_lastMousePosition.y()));
 
-        if (m_layout) {
+        if (m_layout
+            && (std::floor(parentPos.x() / m_layout->cellWidth()) != std::floor(m_lastMousePositionOnGrid.x() / m_layout->cellWidth())
+                || std::floor(parentPos.y() / m_layout->cellHeight()) != std::floor(m_lastMousePositionOnGrid.y() / m_layout->cellHeight()))) {
             m_layout->showPlaceHolderForItem(this);
+            m_lastMousePositionOnGrid = parentPos;
         }
 
         Q_EMIT userDrag(QPointF(x(), y()), event->pos());
     }
-    m_lastMousePosition = event->scenePosition();
+    m_lastMousePosition = parentPos;
     event->accept();
 }
 
